akhdefo_functions.Crop_to_AOI — Akhdefo software documentation

# akhdefo_functions.Crop_to_AOI

akhdefo_functions.Crop_to_AOI(Path_to_WorkingDir='', Path_to_AOI_shapefile='', output_CroppedDir='')

  This program used to clip multiple raster files

  ## Parameters

  Path_to_WorkingDirstr

    path to raster working directory

  Path_to_AOI_shapefilestr

    path to Area of interest in shapefile format

  output_CroppedDirstr

    path to save cropped raster files

  ## Returns

  cropped raster files